#!/usr/bin/env node

const getDistinctUnmetCriteriasByUrl = require('../src/unmet-criteria-by-url-counter')
const generateReport = require('../src/report/reporter');

const { surpassMaxQuantityErrors } = require("../src/surpass-max-quantity-errors");

/**
 * Reads user arguments: reportJsonPath and maxQuantityErrors (optional; defaults to 8, the maximum according to Argentina legislation).
 * Reads the JSON file from reportJsonPath and processes it using {@link getDistinctUnmetCriteriasByUrl},
 * {@link surpassMaxQuantityErrors}, and {@link generateReport}.
 * Exits with the following codes:
 * - 0 if the JSON is valid and meets the quantity criteria.
 * - 1 in case of technical errors.
 * - 2 if the JSON file doesn't meet the valid quantity criteria.
 */
const main = () => {
    try {

        const userArguments = process.argv.slice(2)
        const reportJsonPath = userArguments[0]
        const maxQuantityErrors = userArguments[1];

        console.log("To validate ", reportJsonPath)
        const report = require(reportJsonPath)

        const criteriasUnmetByURLs = getDistinctUnmetCriteriasByUrl(report.results)
        const surpass = surpassMaxQuantityErrors(criteriasUnmetByURLs, maxQuantityErrors)

        generateReport(report.results, criteriasUnmetByURLs, surpass)

        process.exit(surpass ? 2 : 0)
    } catch (e) {
        console.error(e)
        process.exit(1)
    }
}

main()







